%global _incmpidir %{_includedir}/openmpi-%{_arch}
%global _libmpidir %{_libdir}/openmpi/lib
%global _incmpichdir %{_includedir}/mpich-%{_arch}
%global _libmpichdir %{_libdir}/mpich/lib
%global soname_version %%(echo %{version} | cut -d. -f1-2)
%global build_fflags %{build_fflags} -fallow-argument-mismatch

%undefine _ld_as_needed

Summary:   A MUltifrontal Massively Parallel sparse direct Solver
Name:      MUMPS
Version:   5.5.1
Release:   3%{?dist}
License:   CeCILL-C
# URL maybe not available:
# http://mumps.enseeiht.fr
URL:       https://en.wikipedia.org/wiki/MUMPS_(software)
Source0:   https://src.fedoraproject.org/lookaside/extras/MUMPS/%{name}_%{version}.tar.gz
Source1:   %{name}-Makefile.par.inc
Source2:   %{name}-Makefile.seq.inc

Patch3000: %{name}-examples-mpilibs.patch
Patch3001: %{name}-shared-pord.patch
Patch3002: %{name}-shared.patch
Patch3003: %{name}-shared-seq.patch

BuildRequires: make gcc-gfortran gcc pkgconfig(flexiblas) metis-devel scotch-devel scotch-devel-metis
BuildRequires: openssh-clients hwloc-devel
Requires:      %{name}-common = %{version}-%{release}

%description
MUMPS implements a direct solver for large sparse linear systems, with a particular focus on
symmetric positive definite matrices.  It can operate on distributed matrices e.g. over a cluster.
It has Fortran and C interfaces, and can interface with ordering tools such as Scotch.

%package devel
Summary: The MUMPS headers and development-related files
Requires: %{name} = %{version}-%{release}
Requires: gcc-gfortran
Requires: %{name}-srpm-macros = %{version}-%{release}

%description devel
Shared links and header files.  This package contains dummy MPI header file including symbols used by MUMPS.

%package examples
Summary: The MUMPS common illustrative test programs
Requires: %{name} = %{version}-%{release}

%description examples
This package contains common illustrative test programs about how MUMPS can be used.

%package common
Summary: Documentation files for MUMPS
BuildArch: noarch

%description common
This package contains common documentation files for MUMPS.

%package srpm-macros
Summary: Additional RPM macros for MUMPS
BuildArch: noarch

%description srpm-macros
Additional RPM macros for MUMPS.

%package openmpi
Summary: MUMPS libraries compiled against openmpi

BuildRequires:  openmpi-devel blacs-openmpi-devel scalapack-openmpi-devel ptscotch-openmpi-devel
BuildRequires:  ptscotch-openmpi-devel-parmetis rpm-mpi-hooks
Requires: %{name}-common = %{version}-%{release} openmpi scalapack-openmpi ptscotch-openmpi

%description openmpi
MUMPS libraries compiled against openmpi.

%package openmpi-devel
Summary: The MUMPS headers and development-related files
BuildRequires: openmpi-devel
Requires: %{name}-openmpi = %{version}-%{release}  gcc-gfortran
Requires: %{name}-srpm-macros = %{version}-%{release} rpm-mpi-hooks

%description openmpi-devel
Shared links, header files for MUMPS.

%package openmpi-examples
Summary: The MUMPS OpenMPI common illustrative test programs
BuildRequires: rpm-mpi-hooks
Requires: %{name}-openmpi = %{version}-%{release} openmpi

%description openmpi-examples
This package contains common illustrative test programs about how MUMPS-openmpi can be used.

%package mpich
Summary: MUMPS libraries compiled against MPICH
BuildRequires: mpich-devel blacs-mpich-devel scalapack-mpich-devel ptscotch-mpich-devel
BuildRequires: ptscotch-mpich-devel-parmetis rpm-mpi-hooks
Requires: %{name}-common = %{version}-%{release} mpich scalapack-mpich ptscotch-mpich

%description mpich
MUMPS libraries compiled against MPICH.

%package mpich-devel
Summary: The MUMPS headers and development-related files
BuildRequires: mpich-devel
Requires: %{name}-mpich = %{version}-%{release}
Requires: %{name}-srpm-macros = %{version}-%{release}  rpm-mpi-hooks

%description mpich-devel
Shared links, header files for MUMPS.

%package mpich-examples
Summary: The MUMPS MPICH common illustrative test programs
BuildRequires: rpm-mpi-hooks
Requires: %{name}-mpich = %{version}-%{release} gcc-gfortran mpich

%description mpich-examples
This package contains common illustrative test programs about how MUMPS-mpich can be used.

%prep
%setup -q -n %{name}_%{version}
%patch3000 -p1
%patch3001 -p1
%patch3002 -p1

mv examples/README examples/README-examples

%build
rm -f Makefile.inc
%{_openmpi_load}
cp -f %{SOURCE1} Makefile.inc

sed -e 's| -DBLR_MT||g' -i Makefile.inc

%global mpif77_cflags %(env PKG_CONFIG_PATH=%{_libmpidir}/pkgconfig pkg-config --cflags ompi-f77)
%global mpif77_libs %(env PKG_CONFIG_PATH=%{_libmpidir}/pkgconfig pkg-config --libs ompi-f77)
%global mpifort_cflags %(env PKG_CONFIG_PATH=%{_libmpidir}/pkgconfig pkg-config --cflags ompi-fort)
%global mpifort_libs %(env PKG_CONFIG_PATH=%{_libmpidir}/pkgconfig pkg-config --libs ompi-fort)
%global mpic_libs %(env PKG_CONFIG_PATH=%{_libmpidir}/pkgconfig pkg-config --libs ompi)

sed -e 's|@@FFLAGS@@|%{build_fflags} -fPIC -Dscotch -Dmetis -Dptscotch -DWITHOUT_PTHREAD -DINTSIZE32 -I${MPI_FORTRAN_MOD_DIR}|g' -i Makefile.inc
sed -e 's|@@CFLAGS@@|%{build_cflags} -fPIC -Dscotch -Dmetis -Dptscotch -DWITHOUT_PTHREAD -DINTSIZE32|g' -i Makefile.inc
sed -e 's|@@LDFLAGS@@|%{__global_ldflags}|g' -i Makefile.inc
sed -e 's|@@MPICLIB@@|-lmpi|g' -i Makefile.inc
sed -e 's|@@MPIFORTRANLIB@@|-L%{_libmpidir} -Wl,-rpath -Wl,%{_libmpidir} %{mpif77_libs}|g' -i Makefile.inc
sed -e 's|@@MPIFORTRANLIB@@|%{mpifort_libs}|g' -i Makefile.inc

MUMPS_MPI=openmpi
MUMPS_INCDIR=-I$MPI_INCLUDE
LMETISDIR=%{_libdir}
LMETIS="-lmetis -L$MPI_LIB -lptscotchparmetis"
IMETIS=-I%{_includedir}
SCOTCHDIR=$MPI_LIB
ISCOTCH=-I$MPI_INCLUDE/scotch
LSCOTCH=" -L$MPI_LIB -lesmumps -lscotch -lscotcherr -lptesmumps -lptscotch -lptscotcherr"
IPORD=" -I$PWD/PORD/include/"
LPORD=" -L$PWD/PORD/lib -lpord"
FPIC_OPT=-fPIC

export MPIBLACSLIBS=""
export MPI_COMPILER_NAME=openmpi
export LD_LIBRARY_PATH="$MPI_LIB:%{_libdir}"
export LDFLAGS="%{__global_ldflags}"
export LIBBLAS="-L%{_libdir} -lflexiblas"
export INCBLAS=-I%{_includedir}/flexiblas

mkdir -p %{name}-%{version}-$MPI_COMPILER_NAME/lib
mkdir -p %{name}-%{version}-$MPI_COMPILER_NAME/examples
mkdir -p %{name}-%{version}-$MPI_COMPILER_NAME/modules

make all \
 SONAME_VERSION=%{soname_version} \
 CC=$MPI_BIN/mpicc \
 FC=$MPI_BIN/mpif77 \
 FL=$MPI_BIN/mpif77 \
 MUMPS_MPI="$MUMPS_MPI" \
 MUMPS_INCDIR="$MUMPS_INCDIR $INCBLAS" \
 MUMPS_LIBF77="${LIBBLAS} -L$MPI_LIB -Wl,-rpath -Wl,$MPI_LIB %{mpic_libs} $MPIFORTRANSLIB -lscalapack $MPIBLACSLIBS" \
 LMETISDIR="$LMETISDIR" LMETIS="$LMETIS" IMETIS="$IMETIS" \
 SCOTCHDIR=$SCOTCHDIR \
 ISCOTCH=$ISCOTCH \
 LSCOTCH="$LSCOTCH" \
 IPORD="$IPORD" \
 LPORD="$LPORD" \
 OPTL="%{__global_ldflags}"
%{_openmpi_unload}
cp -pr lib/* %{name}-%{version}-$MPI_COMPILER_NAME/lib
cp -pr examples/* %{name}-%{version}-$MPI_COMPILER_NAME/examples
rm -rf lib/*
cp -a include %{name}-%{version}-$MPI_COMPILER_NAME/
cp -pr src/*.mod %{name}-%{version}-$MPI_COMPILER_NAME/modules
make clean

rm -f Makefile.inc
cp -f %{SOURCE1} Makefile.inc

sed -e 's| -DBLR_MT||g' -i Makefile.inc

%{_mpich_load}
%global mpif77_cflags %(env PKG_CONFIG_PATH=%{_libmpichdir}/pkgconfig pkg-config --cflags mpich)
%global mpif77_libs %(env PKG_CONFIG_PATH=%{_libmpichdir}/pkgconfig pkg-config --libs mpich)
%global mpifort_cflags %(env PKG_CONFIG_PATH=%{_libmpichdir}/pkgconfig pkg-config --cflags mpich)
%global mpifort_libs %(env PKG_CONFIG_PATH=%{_libmpichdir}/pkgconfig pkg-config --libs mpich)
%global mpich_libs %(env PKG_CONFIG_PATH=%{_libmpichdir}/pkgconfig pkg-config --libs mpich)

sed -e 's|@@FFLAGS@@|%{build_fflags} -fPIC -Dscotch -Dmetis -Dptscotch -DWITHOUT_PTHREAD -DINTSIZE32 -I${MPI_FORTRAN_MOD_DIR}|g' -i Makefile.inc
sed -e 's|@@LDFLAGS@@|%{__global_ldflags}|g' -i Makefile.inc
sed -e 's|@@CFLAGS@@|%{build_cflags} -fPIC -Dscotch -Dmetis -Dptscotch -DWITHOUT_PTHREAD -DINTSIZE32|g' -i Makefile.inc
sed -e 's|@@MPICLIB@@|-lmpich|g' -i Makefile.inc
sed -e 's|@@MPIFORTRANLIB@@|%{mpifort_libs}|g' -i Makefile.inc

MUMPS_MPI=mpich
MUMPS_INCDIR=-I$MPI_INCLUDE
LMETISDIR=$MPI_LIB
LMETIS="-lmetis -L$MPI_LIB -lptscotchparmetis"
IMETIS=-I%{_includedir}
SCOTCHDIR=$MPI_LIB
ISCOTCH=-I$MPI_INCLUDE/scotch
LSCOTCH="-L$MPI_LIB -lesmumps -lscotch -lscotcherr -lptesmumps -lptscotch -lptscotcherr"
FPIC_OPT=-fPIC
export IPORD=" -I$PWD/PORD/include/"
export LPORD=" -L$PWD/PORD/lib -lpord"
export MPIBLACSLIBS=""
export MPI_COMPILER_NAME=mpich
export LD_LIBRARY_PATH=$MPI_LIB:%{_libdir}
export LDFLAGS="%{__global_ldflags}"
export LIBBLAS="-L%{_libdir} -lflexiblas"
export INCBLAS=-I%{_includedir}/flexiblas

mkdir -p %{name}-%{version}-$MPI_COMPILER_NAME/lib
mkdir -p %{name}-%{version}-$MPI_COMPILER_NAME/examples
mkdir -p %{name}-%{version}-$MPI_COMPILER_NAME/modules

make all \
 SONAME_VERSION=%{soname_version} \
 CC=$MPI_BIN/mpicc \
 FC=$MPI_BIN/mpif77 \
 FL=$MPI_BIN/mpif77 \
 MUMPS_MPI="$MUMPS_MPI" \
 MUMPS_INCDIR="$MUMPS_INCDIR $INCBLAS" \
 MUMPS_LIBF77="${LIBBLAS} -L$MPI_LIB %{mpich_libs} $MPIFORTRANSLIB -lscalapack $MPIBLACSLIBS" \
 LMETISDIR="$LMETISDIR" LMETIS="$LMETIS" IMETIS="$IMETIS" \
 SCOTCHDIR=$SCOTCHDIR \
 ISCOTCH=$ISCOTCH \
 LSCOTCH="$LSCOTCH" \
 IPORD="$IPORD" \
 LPORD="$LPORD" \
 OPTL="%{__global_ldflags}"
%{_mpich_unload}
cp -pr lib/* %{name}-%{version}-$MPI_COMPILER_NAME/lib
cp -pr examples/* %{name}-%{version}-$MPI_COMPILER_NAME/examples
cp -a include %{name}-%{version}-$MPI_COMPILER_NAME/
rm -rf lib/*
cp -pr src/*.mod %{name}-%{version}-$MPI_COMPILER_NAME/modules
make clean

patch -p1 < %{PATCH3003}

rm -f Makefile.inc
cp -f %{SOURCE2} Makefile.inc

sed -e 's| -DBLR_MT||g' -i Makefile.inc
sed -e 's|@@FFLAGS@@|%{build_fflags} -fPIC -Dscotch -Dmetis -DWITHOUT_PTHREAD -DINTSIZE32|g' -i Makefile.inc
sed -e 's|@@LDFLAGS@@|%{__global_ldflags}|g' -i Makefile.inc
sed -e 's|@@CFLAGS@@|%{build_cflags} -fPIC -Dscotch -Dmetis -DWITHOUT_PTHREAD -DINTSIZE32|g' -i Makefile.inc

mkdir -p %{name}-%{version}/lib
mkdir -p %{name}-%{version}/examples
mkdir -p %{name}-%{version}/modules

IPORD=" -I$PWD/PORD/include/"
LPORD=" -L$PWD/PORD/lib -lpord"
FPIC_OPT=-fPIC

export LIBBLAS="-L%{_libdir} -lflexiblas"
export INCBLAS=-I%{_includedir}/flexiblas
export LDFLAGS="%{__global_ldflags}"
make all \
 SONAME_VERSION=%{soname_version} \
 CC=gcc \
 FC=gfortran \
 FL=gfortran \
 MUMPS_LIBF77="${LIBBLAS}" \
 LIBBLAS="${LIBBLAS}" \
 LIBOTHERS=" -lpthread" \
 LIBSEQ="-L../libseq -lmpiseq" \
 INCSEQ="-I../libseq $INCBLAS" \
 LMETISDIR=%{_libdir} \
 IMETIS=-I%{_includedir} \
 LMETIS="-L%{_libdir} -lmetis -lscotchmetis" \
 SCOTCHDIR=%{_prefix} \
 ISCOTCH=-I%{_includedir}/scotch \
 LSCOTCH=" -L%{_libdir} -lesmumps -lscotch -lscotcherr" \
 IPORD="$IPORD" \
 LPORD="$LPORD" \
 OPTL="%{__global_ldflags}"
make -C examples
cp -pr lib/* %{name}-%{version}/lib
cp -pr examples/* %{name}-%{version}/examples
cp -a include %{name}-%{version}/
rm -rf lib/*
cp -pr src/*.mod %{name}-%{version}/modules
make clean

iconv -f iso8859-1 -t utf-8 README > README-t && mv README-t README

%check
pushd %{name}-%{version}/examples
LD_LIBRARY_PATH=$PWD:../lib:$LD_LIBRARY_PATH \
 ./ssimpletest < input_simpletest_real
LD_LIBRARY_PATH=$PWD:../lib:$LD_LIBRARY_PATH \
 ./dsimpletest < input_simpletest_real
LD_LIBRARY_PATH=$PWD:../lib:$LD_LIBRARY_PATH \
 ./csimpletest < input_simpletest_cmplx
LD_LIBRARY_PATH=$PWD:../lib:$LD_LIBRARY_PATH \
 ./zsimpletest < input_simpletest_cmplx
LD_LIBRARY_PATH=$PWD:../lib:$LD_LIBRARY_PATH \
 ./c_example
popd

%{_openmpi_load}
pushd %{name}-%{version}-openmpi/examples
export LD_LIBRARY_PATH=$PWD:../lib:$LD_LIBRARY_PATH
export OMPI_MCA_rmaps_base_oversubscribe=1
./ssimpletest < input_simpletest_real
./dsimpletest < input_simpletest_real
./csimpletest < input_simpletest_cmplx
./zsimpletest < input_simpletest_cmplx
mpirun -np 3 ./c_example
popd
%{_openmpi_unload}

%install
%{_openmpi_load}
mkdir -p %{buildroot}$MPI_LIB
mkdir -p %{buildroot}%{_libdir}/openmpi/%{name}-%{version}-examples
mkdir -p %{buildroot}$MPI_INCLUDE
mkdir -p %{buildroot}$MPI_FORTRAN_MOD_DIR/%{name}-%{version}

install -cpm 755 %{name}-%{version}-openmpi/lib/lib*-*.so %{buildroot}$MPI_LIB
install -cpm 755 %{name}-%{version}-openmpi/lib/libmumps_common.so %{buildroot}$MPI_LIB
install -cpm 755 %{name}-%{version}-openmpi/lib/lib*mumps.so %{buildroot}$MPI_LIB
install -cpm 755 %{name}-%{version}-openmpi/lib/lib*mumps-%{soname_version}.so %{buildroot}$MPI_LIB
install -cpm 755 %{name}-%{version}-openmpi/lib/libpord-%{soname_version}.so %{buildroot}$MPI_LIB
install -cpm 755 %{name}-%{version}-openmpi/lib/libpord.so %{buildroot}$MPI_LIB

ln -sf $MPI_LIB/libsmumps-%{soname_version}.so %{buildroot}$MPI_LIB/libsmumps.so
ln -sf $MPI_LIB/libcmumps-%{soname_version}.so %{buildroot}$MPI_LIB/libcmumps.so
ln -sf $MPI_LIB/libzmumps-%{soname_version}.so %{buildroot}$MPI_LIB/libzmumps.so
ln -sf $MPI_LIB/libdmumps-%{soname_version}.so %{buildroot}$MPI_LIB/libdmumps.so
ln -sf $MPI_LIB/libmumps_common-%{soname_version}.so %{buildroot}$MPI_LIB/libmumps_common.so
ln -sf $MPI_LIB/libpord-%{soname_version}.so %{buildroot}$MPI_LIB/libpord.so

install -cpm 755 %{name}-%{version}-openmpi/examples/?simpletest %{buildroot}%{_libdir}/openmpi/%{name}-%{version}-examples
install -cpm 755 %{name}-%{version}-openmpi/examples/input_* %{buildroot}%{_libdir}/openmpi/%{name}-%{version}-examples
install -cpm 755 %{name}-%{version}-openmpi/examples/README-* %{buildroot}%{_libdir}/openmpi/%{name}-%{version}-examples

install -cpm 644 %{name}-%{version}-openmpi/include/*.h %{buildroot}$MPI_INCLUDE
install -cpm 644 PORD/include/* %{buildroot}$MPI_INCLUDE
install -cpm 644 %{name}-%{version}-openmpi/modules/* %{buildroot}$MPI_FORTRAN_MOD_DIR/%{name}-%{version}/
%{_openmpi_unload}

%{_mpich_load}
mkdir -p %{buildroot}$MPI_LIB
mkdir -p %{buildroot}%{_libdir}/mpich/%{name}-%{version}-examples
mkdir -p %{buildroot}$MPI_INCLUDE
mkdir -p %{buildroot}$MPI_FORTRAN_MOD_DIR/%{name}-%{version}

install -cpm 755 %{name}-%{version}-mpich/lib/lib*-*.so %{buildroot}$MPI_LIB
install -cpm 755 %{name}-%{version}-mpich/lib/libmumps_common.so %{buildroot}$MPI_LIB
install -cpm 755 %{name}-%{version}-mpich/lib/lib*mumps.so %{buildroot}$MPI_LIB
install -cpm 755 %{name}-%{version}-mpich/lib/lib*mumps-%{soname_version}.so %{buildroot}$MPI_LIB
install -cpm 755 %{name}-%{version}-mpich/lib/libpord-%{soname_version}.so %{buildroot}$MPI_LIB
install -cpm 755 %{name}-%{version}-mpich/lib/libpord.so %{buildroot}$MPI_LIB

ln -sf $MPI_LIB/libsmumps-%{soname_version}.so %{buildroot}$MPI_LIB/libsmumps.so
ln -sf $MPI_LIB/libcmumps-%{soname_version}.so %{buildroot}$MPI_LIB/libcmumps.so
ln -sf $MPI_LIB/libzmumps-%{soname_version}.so %{buildroot}$MPI_LIB/libzmumps.so
ln -sf $MPI_LIB/libdmumps-%{soname_version}.so %{buildroot}$MPI_LIB/libdmumps.so
ln -sf $MPI_LIB/libmumps_common-%{soname_version}.so %{buildroot}$MPI_LIB/libmumps_common.so
ln -sf $MPI_LIB/libpord-%{soname_version}.so %{buildroot}$MPI_LIB/libpord.so

install -cpm 755 %{name}-%{version}-mpich/examples/?simpletest %{buildroot}%{_libdir}/mpich/%{name}-%{version}-examples
install -cpm 755 %{name}-%{version}-mpich/examples/input_* %{buildroot}%{_libdir}/mpich/%{name}-%{version}-examples
install -cpm 755 %{name}-%{version}-mpich/examples/README-* %{buildroot}%{_libdir}/mpich/%{name}-%{version}-examples

install -cpm 644 %{name}-%{version}-mpich/include/*.h %{buildroot}$MPI_INCLUDE
install -cpm 644 PORD/include/* %{buildroot}$MPI_INCLUDE
install -cpm 644 %{name}-%{version}-mpich/modules/* %{buildroot}$MPI_FORTRAN_MOD_DIR/%{name}-%{version}/
%{_mpich_unload}

mkdir -p %{buildroot}%{_libexecdir}/%{name}-%{version}/examples
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_includedir}/%{name}
mkdir -p %{buildroot}%{_fmoddir}/%{name}-%{version}

install -cpm 755 %{name}-%{version}/lib/lib*-*.so %{buildroot}%{_libdir}/

ln -sf libsmumps-%{soname_version}.so %{buildroot}%{_libdir}/libsmumps.so
ln -sf libcmumps-%{soname_version}.so %{buildroot}%{_libdir}/libcmumps.so
ln -sf libzmumps-%{soname_version}.so %{buildroot}%{_libdir}/libzmumps.so
ln -sf libdmumps-%{soname_version}.so %{buildroot}%{_libdir}/libdmumps.so
ln -sf libmumps_common-%{soname_version}.so %{buildroot}%{_libdir}/libmumps_common.so
ln -sf libpord-%{soname_version}.so %{buildroot}%{_libdir}/libpord.so
ln -sf libmpiseq-%{soname_version}.so %{buildroot}%{_libdir}/libmpiseq.so

install -cpm 755 %{name}-%{version}/examples/?simpletest %{buildroot}%{_libexecdir}/%{name}-%{version}/examples
install -cpm 755 %{name}-%{version}/examples/input_* %{buildroot}%{_libexecdir}/%{name}-%{version}/examples
install -cpm 755 %{name}-%{version}/examples/README-* %{buildroot}%{_libexecdir}/%{name}-%{version}/examples
install -cpm 644 %{name}-%{version}/modules/* %{buildroot}%{_fmoddir}/%{name}-%{version}/
install -cpm 644 %{name}-%{version}/include/*.h %{buildroot}%{_includedir}/%{name}
install -cpm 644 libseq/*.h %{buildroot}%{_includedir}/%{name}
install -cpm 644 PORD/include/* %{buildroot}%{_includedir}/%{name}

mkdir -p %{buildroot}%{_rpmmacrodir}
cat > %{buildroot}%{_rpmmacrodir}/macros.MUMPS <<EOF
%%_MUMPS_version %{version}
EOF

%files openmpi
%{_libmpidir}/libpord-%{soname_version}.so
%{_libmpidir}/lib?mumps-%{soname_version}.so
%{_libmpidir}/libmumps_common-%{soname_version}.so

%files openmpi-devel
%{_incmpidir}/*.h
%{_libmpidir}/lib?mumps.so
%{_libmpidir}/libmumps_common.so
%{_libmpidir}/libpord.so
%{_fmoddir}/openmpi/%{name}-%{version}/

%files openmpi-examples
%{_libdir}/openmpi/%{name}-%{version}-examples/

%files mpich
%{_libmpichdir}/libpord-%{soname_version}.so
%{_libmpichdir}/lib?mumps-%{soname_version}.so
%{_libmpichdir}/libmumps_common-%{soname_version}.so

%files mpich-devel
%{_incmpichdir}/*.h
%{_libmpichdir}/lib?mumps.so
%{_libmpichdir}/libmumps_common.so
%{_libmpichdir}/libpord.so
%{_fmoddir}/mpich/%{name}-%{version}/

%files mpich-examples
%{_libdir}/mpich/%{name}-%{version}-examples/

%files
%{_libdir}/libpord-%{soname_version}.so
%{_libdir}/libmpiseq-%{soname_version}.so
%{_libdir}/lib?mumps-%{soname_version}.so
%{_libdir}/libmumps_common-%{soname_version}.so

%files devel
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%{_fmoddir}/%{name}-%{version}/
%{_libdir}/lib?mumps.so
%{_libdir}/libmumps_common.so
%{_libdir}/libpord.so
%{_libdir}/libmpiseq.so

%files examples
%{_libexecdir}/%{name}-%{version}/

%files common
%license LICENSE
%doc doc/*.pdf ChangeLog README

%files srpm-macros
%{_rpmmacrodir}/macros.MUMPS

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.5.1-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.5.1-2
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 26 2023 Shuo Wang <abushwang@tencent.com> - 5.5.1-1
- initial build
